@@ -443,6 +443,13 @@ int msg_convert(GMimeObject *part, GMimeObject **new, harmless_proc_arg_t *arg)
                 }
                 break;
             case COMMAND:
+                // ファイル名を環境変数に設定
+                if (setenv(ENV_FILENAME, filename, 1) != 0) {
+                    output_conv_log(CONV_ERR_EXEC_ENV, c_p->command_name, arg->maildata);
+                    free(content_type);
+                    return HARMLESS_NG;
+                }
+
                 _ret = exec_command_with_gmime(part, new, c_p->arg_list, arg);
                 if (_ret == HARMLESS_NG) {
                     output_conv_log(CONV_ERR_EXEC_EXT, c_p->command_name, arg->maildata);
@@ -450,7 +457,7 @@ int msg_convert(GMimeObject *part, GMimeObject **new, harmless_proc_arg_t *arg)
                     return HARMLESS_NG;
                 }
                 // mimetypeを更新
-                if (GMIME_IS_OBJECT(*new)) {
+                if (GMIME_IS_OBJECT(*new) && strcmp(c_p->mime_after, "-")) {
                     GMimeContentType *newtype = g_mime_content_type_new_from_string(c_p->mime_after);
                     g_mime_object_set_content_type((GMimeObject *)*new, newtype);
                     g_object_unref(newtype);
